package com.cool.bang.modules.mysql.domain;

import java.math.BigDecimal;
import java.util.Date;
import java.util.Map;

/**
 * 项目表
 *
 * @author PeiZhi Guo
 * 2022-08-03 15:39
 */
public class Project {

    private static final long serialVersionUID = 1L;

    private Long id;

    /** 企业ID */
    private Integer orgId;

    /** 企业名称 */
    private String orgName;

    /** 项目编号（项目唯一识别码） */
    private String projectNumber;

    /** 项目名称 */
    private String projectName;

    /** 项目坐落 */
    private String projectAddress;

    /** 监管面积 */
    private BigDecimal buildArea;

    /** 监管楼幢 */
    private Integer buildingTotal;

    /** 套数 */
    private Integer houseTotal;

    /** 建筑成本ID */
    private Long buildCostId;

    /** 建筑成本名称 */
    private String buildCostName;

    /** 调剂比例 */
    private BigDecimal adjustmentPercentage;

    /** 银行保证函抵扣比例 */
    private BigDecimal bankPercentage;

    /** 是否冻结 0否 1是 冻结只能进不能出 */
    private Integer isFrozen;

    /** 监管类型 1托管 2监管 */
    private Integer type;

    /** 项目状态  0解除监管 1正常  2申请解除监管 */
    private Integer state;

    private Date createTime;

    /** 删除标识 1正常 0删除 */
    private Integer delFlag;

    public Project(){}

    public Project(Map<String,Object> map){
        /**
         *   BXM的QYBH --> BQY的QYBH --> p_qyxx表中的misid
         *   p_qyxx表中的id --> fc_project表中的org_id
         */
        this.orgName = (String) map.get("QYMC");
        this.projectNumber = (String) map.get("XMBH");
        this.projectName = (String) map.get("XMMC");
        this.projectAddress = (String) map.get("XMDZ");
        this.buildArea = (BigDecimal) map.get("XMYSMJ");
        if (this.buildArea.compareTo(new BigDecimal("0")) == 0) {
            this.buildArea = (BigDecimal) map.get("XMJZMJ");
        }
        this.buildingTotal = Integer.parseInt(map.get("XMZLZS").toString().trim());
        this.houseTotal = (Integer) map.get("");
        this.buildCostId = (Long) map.get("");
        this.buildCostName = (String) map.get("");
        this.adjustmentPercentage = BigDecimal.ZERO;
        this.bankPercentage = BigDecimal.ZERO;
        this.isFrozen = 0;
        this.type = typeSwitch(Integer.parseInt(map.get("JGLX").toString()));
        this.state = stateSwitch(Integer.parseInt(map.get("JGZT").toString()));
        this.createTime =  (Date) map.get("SPJSSJ");
        this.delFlag = 1;
    }

    private Integer typeSwitch(Integer data) {
        if (data == null) { //如果为空默认为监管模式
            return 2;
        }
        switch (data) {
            case 1:
                return 1;
            default:
                return 2;
        }
    }

    private Integer stateSwitch(Integer type) {
        if (type == null) { //如果为空默认为正在监管状态
            return 3;
        }
        switch (type) {
            case 0:
                return 0;
            case 1:
                return 1;
            case -1:
                return 0;
            default:
                return 3;
        }
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getOrgId() {
        return orgId;
    }

    public void setOrgId(Integer orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getProjectNumber() {
        return projectNumber;
    }

    public void setProjectNumber(String projectNumber) {
        this.projectNumber = projectNumber;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }

    public BigDecimal getBuildArea() {
        return buildArea;
    }

    public void setBuildArea(BigDecimal buildArea) {
        this.buildArea = buildArea;
    }

    public Integer getBuildingTotal() {
        return buildingTotal;
    }

    public void setBuildingTotal(Integer buildingTotal) {
        this.buildingTotal = buildingTotal;
    }

    public Integer getHouseTotal() {
        return houseTotal;
    }

    public void setHouseTotal(Integer houseTotal) {
        this.houseTotal = houseTotal;
    }

    public Long getBuildCostId() {
        return buildCostId;
    }

    public void setBuildCostId(Long buildCostId) {
        this.buildCostId = buildCostId;
    }

    public String getBuildCostName() {
        return buildCostName;
    }

    public void setBuildCostName(String buildCostName) {
        this.buildCostName = buildCostName;
    }

    public BigDecimal getAdjustmentPercentage() {
        return adjustmentPercentage;
    }

    public void setAdjustmentPercentage(BigDecimal adjustmentPercentage) {
        this.adjustmentPercentage = adjustmentPercentage;
    }

    public BigDecimal getBankPercentage() {
        return bankPercentage;
    }

    public void setBankPercentage(BigDecimal bankPercentage) {
        this.bankPercentage = bankPercentage;
    }

    public Integer getIsFrozen() {
        return isFrozen;
    }

    public void setIsFrozen(Integer isFrozen) {
        this.isFrozen = isFrozen;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Integer getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}
